Reel
========

A package for async subprocesses.


Motivation
----------

This project is a simplified version of Python subprocess control with
asynchronous support.  It is being developed to support a music streaming
package which uses ffmpeg and other shell commands to get music from various
sources to various destinations.
